@@ -1,5 +1,5 @@
-"""Top-level package for Data tools."""
+"""Top-level package for datools."""
 
 __author__ = """Adam Marcus"""
 __email__ = 'marcua@marcua.net'
-__version__ = '0.1.3'
+__version__ = '0.1.4'
