@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 
+from pytest import approx
+from sqlalchemy.engine import Engine
+
 from datools.models import Column
 from datools.models import Constant
 from datools.models import Explanation
@@ -9,10 +12,10 @@ from datools.explanations import diff
 from .fixtures import generate_scorpion_testdb
 
 
-def test_diff():
-    engine = generate_scorpion_testdb()
+def test_diff(db_engine: Engine):
+    generate_scorpion_testdb(db_engine)
     candidates = diff(
-        engine,
+        db_engine,
         'SELECT * FROM sensor_readings WHERE temperature > 50',
         'SELECT * FROM sensor_readings WHERE temperature <= 50',
         {Column('created_at'), Column('sensor_id'), Column('voltage'),
@@ -24,7 +27,7 @@ def test_diff():
     assert(candidates == [
         Explanation(
             (Predicate(
-                Column('voltage'), Operator.EQUALS, Constant(2.3)), ),
+                Column('voltage'), Operator.EQUALS, Constant(approx(2.3))), ),
             risk_ratio=9.0),
         Explanation(
             (Predicate(Column('sensor_id'), Operator.EQUALS, Constant('3')), ),
